Name:		HepMC3
Version:	3.1.0
Release:	3%{?dist}
Summary:	C++ Event Record for Monte Carlo Generators

License:	GPLv2+
URL:		https://hepmc.web.cern.ch/hepmc/
Source0:	https://hepmc.web.cern.ch/hepmc/releases/%{name}-%{version}.tar.gz
#		https://gitlab.cern.ch/hepmc/HepMC3/merge_requests/7
Patch0:		0001-Install-the-rootmap-file-together-with-the-pcm-file-.patch
Patch1:		0002-Avoid-overlinking.-Only-link-against-those-ROOT-libr.patch
Patch2:		0003-Fix-segfault-in-test-that-tries-to-modify-the-elemen.patch
Patch3:		0004-Fix-the-memcheck-tests.patch
Patch4:		0005-The-memcheck-and-non-memcheck-version-of-the-same-te.patch
#		Ported from upstream's git
Patch5:		0001-CMake-changes.patch
Patch6:		0001-Added-soversion.patch
Patch7:		0001-Attempt-to-fix-HepMC3Config.patch
#		Increase test timeout (from upstream's git)
Patch8:		%{name}-test-timeout.patch

#		The ROOT cmake file used by this project requires cmake 3.4.3
%if %{?fedora}%{!?fedora:0} || %{?rhel}%{!?rhel:0} >= 8
BuildRequires:	cmake >= 3.4.3
%else
BuildRequires:	cmake3 >= 3.4.3
%endif
BuildRequires:	gcc-c++
%ifnarch s390x
BuildRequires:	root-core
BuildRequires:	root-hist
BuildRequires:	root-io
BuildRequires:	root-tree
%endif
BuildRequires:	doxygen
BuildRequires:	graphviz
#		Additional requirements for tests
BuildRequires:	pythia8-devel

%description
The HepMC3 package is an object oriented, C++ event record for
High Energy Physics Monte Carlo generators and simulation.
Since the first implementation, described in M. Dobbs and J.B. Hansen
(Comput. Phys. Commun. 134 (2001) 41), the package has undergone
several modifications and in particular, the latest HepMC3 series is a
completely new re-write using currently available C++11 techniques.

%package devel
Summary:	C++ Event Record for Monte Carlo Generators - development files
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
This package provides development files for %{name}.

%package search
Summary:	C++ Event Record for Monte Carlo Generators - search engine library
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description search
This package provides a library for selecting particles in HepMC3 event
records.

%package search-devel
Summary:	C++ Event Record for Monte Carlo Generators - %{name}-search development files
Requires:	%{name}-search%{?_isa} = %{version}-%{release}
Requires:	%{name}-devel%{?_isa} = %{version}-%{release}

%description search-devel
This package provides development files for %{name}-search.

%ifnarch s390x
%package rootIO
Summary:	C++ Event Record for Monte Carlo Generators - ROOT IO
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description rootIO
This package provides a library for ROOT IO support.

%package rootIO-devel
Summary:	C++ Event Record for Monte Carlo Generators - %{name}-rootIO development files
Requires:	%{name}-rootIO%{?_isa} = %{version}-%{release}
Requires:	%{name}-devel%{?_isa} = %{version}-%{release}

%description rootIO-devel
This package provides development files for %{name}-rootIO.
%endif

%package interfaces-devel
Summary:	C++ Event Record for Monte Carlo Generators - generator interfaces
Requires:	%{name}-devel = %{version}-%{release}
BuildArch:	noarch

%description interfaces-devel
This package provides HepMC3 interfaces to some common Monte Carlo generators.

%package doc
Summary:	C++ Event Record for Monte Carlo Generators - documentation
BuildArch:	noarch

%description doc
This package provides HepMC manuals and examples.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
%if %{?fedora}%{!?fedora:0} || %{?rhel}%{!?rhel:0} >= 8
%cmake \
%else
%cmake3 \
%endif
%ifnarch s390x
	-DHEPMC3_ENABLE_ROOTIO:BOOL=ON \
%else
	-DHEPMC3_ENABLE_ROOTIO:BOOL=OFF \
%endif
	-DHEPMC3_ENABLE_TEST:BOOL=ON -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON .
make %{?_smp_mflags}
make -C doc/doxygen

%install
make install DESTDIR=%{buildroot}
rm %{buildroot}%{_libdir}/*.a
mkdir -p %{buildroot}%{_pkgdocdir}
mv doc/doxygen/html %{buildroot}%{_pkgdocdir}
cp -pr examples %{buildroot}%{_pkgdocdir}
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr interfaces %{buildroot}%{_datadir}/%{name}

# Fix shebang
sed 's!/usr/bin/env bash!/bin/bash!' -i %{buildroot}%{_bindir}/HepMC3-config

%ifnarch s390x
# Move to root directory
mkdir %{buildroot}%{_libdir}/root
mv %{buildroot}%{_libdir}/libHepMC3rootIO.so* %{buildroot}%{_libdir}/root
mv %{buildroot}%{_libdir}/librootIO_Classes* %{buildroot}%{_libdir}/root
sed 's!\s*-lHepMC3rootIO!/root&!' -i %{buildroot}%{_bindir}/HepMC3-config
sed 's!HepMCrootIO HINTS .*%{_lib}!&/root!' -i %{buildroot}%{_datadir}/%{name}/cmake/HepMC3Config.cmake
%endif

%check
%if %{?fedora}%{!?fedora:0} || %{?rhel}%{!?rhel:0} >= 8
ctest %{?_smp_mflags} --output-on-failure
%else
ctest3 %{?_smp_mflags} --output-on-failure
%endif

%ldconfig_scriptlets
%ldconfig_scriptlets search
%ifnarch s390x
%ldconfig_scriptlets rootIO
%endif

%files
%{_libdir}/libHepMC3.so.1
%license COPYING

%files devel
%{_bindir}/HepMC3-config
%{_libdir}/libHepMC3.so
%dir %{_includedir}/%{name}
%dir %{_includedir}/%{name}/Data
%{_includedir}/%{name}/AssociatedParticle.h
%{_includedir}/%{name}/Attribute.h
%{_includedir}/%{name}/Data/GenEventData.h
%{_includedir}/%{name}/Data/GenParticleData.h
%{_includedir}/%{name}/Data/GenRunInfoData.h
%{_includedir}/%{name}/Data/GenVertexData.h
%{_includedir}/%{name}/Errors.h
%{_includedir}/%{name}/FourVector.h
%{_includedir}/%{name}/GenCrossSection.h
%{_includedir}/%{name}/GenCrossSection_fwd.h
%{_includedir}/%{name}/GenEvent.h
%{_includedir}/%{name}/GenHeavyIon.h
%{_includedir}/%{name}/GenHeavyIon_fwd.h
%{_includedir}/%{name}/GenParticle.h
%{_includedir}/%{name}/GenParticle_fwd.h
%{_includedir}/%{name}/GenPdfInfo.h
%{_includedir}/%{name}/GenPdfInfo_fwd.h
%{_includedir}/%{name}/GenRunInfo.h
%{_includedir}/%{name}/GenVertex.h
%{_includedir}/%{name}/GenVertex_fwd.h
%{_includedir}/%{name}/HEPEVT_Wrapper.h
%{_includedir}/%{name}/HepMC3.h
%{_includedir}/%{name}/LHEF.h
%{_includedir}/%{name}/LHEFAttributes.h
%{_includedir}/%{name}/Print.h
%{_includedir}/%{name}/Reader.h
%{_includedir}/%{name}/ReaderAscii.h
%{_includedir}/%{name}/ReaderAsciiHepMC2.h
%{_includedir}/%{name}/ReaderFactory.h
%{_includedir}/%{name}/ReaderHEPEVT.h
%{_includedir}/%{name}/ReaderLHEF.h
%{_includedir}/%{name}/Setup.h
%{_includedir}/%{name}/Units.h
%{_includedir}/%{name}/Version.h
%{_includedir}/%{name}/Writer.h
%{_includedir}/%{name}/WriterAscii.h
%{_includedir}/%{name}/WriterAsciiHepMC2.h
%{_includedir}/%{name}/WriterHEPEVT.h
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/cmake
%{_datadir}/%{name}/cmake/HepMC3Config.cmake

%files search
%{_libdir}/libHepMC3search.so.1

%files search-devel
%{_libdir}/libHepMC3search.so
%{_includedir}/%{name}/AttributeFeature.h
%{_includedir}/%{name}/Feature.h
%{_includedir}/%{name}/Filter.h
%{_includedir}/%{name}/FilterAttribute.h
%{_includedir}/%{name}/Relatives.h
%{_includedir}/%{name}/Selector.h

%ifnarch s390x
%files rootIO
%{_libdir}/root/libHepMC3rootIO.so.1
# unversioned symlink is used at runtime when library is used as a ROOT plugin
%{_libdir}/root/libHepMC3rootIO.so
%{_libdir}/root/librootIO_Classes_rdict.pcm
%{_libdir}/root/librootIO_Classes.rootmap

%files rootIO-devel
%{_includedir}/%{name}/ReaderRoot.h
%{_includedir}/%{name}/ReaderRootTree.h
%{_includedir}/%{name}/WriterRoot.h
%{_includedir}/%{name}/WriterRootTree.h
%endif

%files interfaces-devel
%{_datadir}/%{name}/interfaces

%files doc
%dir %{_pkgdocdir}
%{_pkgdocdir}/examples
%{_pkgdocdir}/html
%license COPYING

%changelog
* Tue Mar 05 2019 Mattias Ellert <mattias.ellert@physics.uu.se> - 3.1.0-3
- Rename interfaces subpackage to interfaces-devel
- Add patch fixing installed cmake file from upstream
- Increase test timeout

* Tue Mar 05 2019 Mattias Ellert <mattias.ellert@physics.uu.se> - 3.1.0-2
- Add soversion patch from upstream

* Fri Feb 22 2019 Mattias Ellert <mattias.ellert@physics.uu.se> - 3.1.0-1
- Initial build
